@@ -9,3 +9,5 @@ dumb_player = _read('dumb_player')
 err_syntax = _read('err_syntax')
 err_divzero = _read('err_divzero')
 err_badfun = _read('err_badfun')
+err_oom = _read('err_oom')
+err_timeout = _read('err_timeout')
